@@ -5,7 +5,7 @@ web2ldap.app.addmodifyform: input form for adding and modifying an entry
 web2ldap - a web-based LDAP Client,
 see https://www.web2ldap.de for details
 
-(c) 1998-2020 by Michael Stroeder <michael@stroeder.com>
+(c) 1998-2021 by Michael Stroeder <michael@stroeder.com>
 
 This software is distributed under the terms of the
 Apache License Version 2.0 (Apache-2.0)
@@ -549,14 +549,16 @@ class InputFormEntry(web2ldap.app.read.DisplayEntry):
         # end of ldif_input()
 
 
-def SupentryDisplayString(app, parent_dn, supentry_display_tmpl=None):
-    supentry_display_tmpl = supentry_display_tmpl or \
-        r"""
-        <p title="Superior entry information">
-          <strong>Superior entry:</strong><br>
-          %s
-        </p>
-        """
+def superior_display_html(
+        app,
+        parent_dn,
+        supentry_display_tmpl=(
+            '<p title="Superior entry information">'
+            '<strong>Superior entry:</strong><br>'
+            '{0}'
+            '</p>'
+        ),
+    ):
     assert isinstance(parent_dn, str), TypeError("Argument 'parent_dn' must be str, was %r" % (parent_dn))
     if parent_dn is None:
         return ''
@@ -591,11 +593,11 @@ def SupentryDisplayString(app, parent_dn, supentry_display_tmpl=None):
                     else:
                         supentry_display_strings.append(inputform_supentrytemplate[oc] % parent_entry)
     if supentry_display_strings:
-        return supentry_display_tmpl % ('\n'.join(supentry_display_strings))
+        return supentry_display_tmpl.format('\n'.join(supentry_display_strings))
     return app.form.utf2display(parent_dn)
 
 
-def ObjectClassForm(
+def object_class_form(
         app,
         existing_object_classes,
         structural_object_class
@@ -660,7 +662,7 @@ def ObjectClassForm(
         return all_structural_oc, dit_structure_rule_html # get_possible_soc()
 
 
-    def ExpertOCFields(app, parent_dn):
+    def object_class_select_fields(app, parent_dn):
 
         all_structural_oc, all_abstract_oc, all_auxiliary_oc = web2ldap.app.schema.object_class_categories(app.schema, all_oc)
         dit_structure_rule_html = ''
@@ -805,10 +807,10 @@ def ObjectClassForm(
         }[app.command]
         Msg = '<p class="WarningMessage">%s</p>' % (Msg)
         return Msg, add_template_field_html
-        # end of ExpertOCFields()
+        # end of object_class_select_fields()
 
 
-    def LDIFTemplateField(app, parent_dn):
+    def ldif_template_select_html(app, parent_dn):
         all_structural_oc, _, _ = web2ldap.app.schema.object_class_categories(app.schema, all_oc)
         addform_entry_templates_keys = list(app.cfg_param('addform_entry_templates', {}).keys())
         addform_parent_attrs = app.cfg_param('addform_parent_attrs', [])
@@ -879,7 +881,7 @@ def ObjectClassForm(
         add_template_html_list = ['<dl>']
         for pdn in sorted(add_tmpl_dict.keys()):
             add_template_html_list.append('<dt>%s<dt>' % (
-                SupentryDisplayString(app, pdn, supentry_display_tmpl=r'%s'),
+                superior_display_html(app, pdn, supentry_display_tmpl='{0}'),
             ))
             add_template_html_list.append('<dd><ul>')
             for tmpl_name in add_tmpl_dict[pdn]:
@@ -900,7 +902,8 @@ def ObjectClassForm(
         add_template_html_list.append('</dl>')
         add_template_field_html = '\n'.join(add_template_html_list)
         Msg = '<p class="WarningMessage">Choose a LDIF template and base DN for new entry</p>'
-        return Msg, add_template_field_html # LDIFTemplateField()
+        return Msg, add_template_field_html
+        # end of ldif_template_select_html()
 
 
     in_ocf = app.form.getInputValue('in_ocf', ['tmpl'])[0]
@@ -923,9 +926,9 @@ def ObjectClassForm(
 
     # Build an select field based on config param 'addform_entry_templates'
     if app.command == 'add' and in_ocf == 'tmpl':
-        Msg, add_template_field_html = LDIFTemplateField(app, parent_dn)
+        Msg, add_template_field_html = ldif_template_select_html(app, parent_dn)
     else:
-        Msg, add_template_field_html = ExpertOCFields(app, parent_dn)
+        Msg, add_template_field_html = object_class_select_fields(app, parent_dn)
 
     context_menu_list = []
     if app.command == 'add':
@@ -958,7 +961,7 @@ def ObjectClassForm(
         )
     )
     web2ldap.app.gui.footer(app)
-    # end of ObjectClassForm()
+    # end of object_class_form()
 
 
 def read_ldif_template(app, template_name):
@@ -1010,15 +1013,15 @@ def ConfiguredConstantAttributes(app):
     )
 
 
-def AssertionFilter(app, entry):
-    assertion_filter_list = []
+def assertion_filter(app, entry):
+    filter_list = []
     for attr_type in ConfiguredConstantAttributes(app).values():
         try:
             attr_values = entry[attr_type]
         except KeyError:
             continue
         else:
-            assertion_filter_list.extend([
+            filter_list.extend([
                 '(%s)' % (
                     '='.join((
                         attr_type,
@@ -1028,11 +1031,12 @@ def AssertionFilter(app, entry):
                 for attr_value in attr_values
                 if attr_value is not None
             ])
-    if assertion_filter_list:
-        assertion_filter = '(&%s)' % ''.join(assertion_filter_list)
+    if filter_list:
+        res = '(&%s)' % ''.join(filter_list)
     else:
-        assertion_filter = '(objectClass=*)'
-    return assertion_filter # AssertionFilter()
+        res = '(objectClass=*)'
+    return res
+    # end of assertion_filter()
 
 
 def nomatching_attrs(sub_schema, entry, allowed_attrs_dict, required_attrs_dict):
@@ -1161,7 +1165,7 @@ def w2l_addform(app, add_rdn, add_basedn, entry, msg='', invalid_attrs=None):
 
     if input_formtype == 'OC' or not entry:
         # Output the web page with object class input form
-        ObjectClassForm(app, decode_list(entry.get('objectClass', []), 'ascii'), None)
+        object_class_form(app, decode_list(entry.get('objectClass', []), 'ascii'), None)
         return
 
     input_form_entry = InputFormEntry(app, app.dn, app.schema, entry, None, invalid_attrs=invalid_attrs)
@@ -1170,8 +1174,6 @@ def w2l_addform(app, add_rdn, add_basedn, entry, msg='', invalid_attrs=None):
 
     rdn_options = input_form_entry.entry.get_rdn_templates()
 
-    supentry_display_string = SupentryDisplayString(app, add_basedn)
-
     if rdn_options and len(rdn_options) > 0:
         # <select> field
         rdn_input_field = web2ldap.web.forms.Select('add_rdn', 'RDN variants', 1, options=rdn_options)
@@ -1222,7 +1224,7 @@ def w2l_addform(app, add_rdn, add_basedn, entry, msg='', invalid_attrs=None):
         INPUT_FORM_BEGIN_TMPL.format(
             text_heading=H1_MSG[app.command],
             text_msg=msg,
-            text_supentry=supentry_display_string,
+            text_supentry=superior_display_html(app, add_basedn),
             form_begin=app.begin_form(app.command, 'POST', enctype='multipart/form-data'),
             field_dn=app.form.hiddenFieldHTML('dn', app.dn, ''),
             field_currentformtype=app.form.hiddenFieldHTML('in_oft', str(input_formtype), ''),
@@ -1280,13 +1282,13 @@ def w2l_modifyform(app, entry, msg='', invalid_attrs=None):
     if in_wrtattroids == ['nonePseudoValue;x-web2ldap-None']:
         writeable_attr_oids = None
     elif in_wrtattroids:
-        writeable_attr_oids = {a for a in in_wrtattroids}
+        writeable_attr_oids = set(in_wrtattroids)
     else:
         writeable_attr_oids = read_writeable_attr_oids
 
     if input_formtype == 'OC':
         # Output the web page with object class input form
-        ObjectClassForm(app, decode_list(entry['objectClass'], 'ascii'), entry.get_structural_oc())
+        object_class_form(app, decode_list(entry['objectClass'], 'ascii'), entry.get_structural_oc())
         return
 
     existing_object_classes = decode_list(entry['objectClass'][:], encoding='ascii')
@@ -1298,8 +1300,6 @@ def w2l_modifyform(app, entry, msg='', invalid_attrs=None):
     required_attrs_dict, allowed_attrs_dict = input_form_entry.attribute_types()
     nomatching_attrs_dict = nomatching_attrs(app.schema, input_form_entry, allowed_attrs_dict, required_attrs_dict)
 
-    supentry_display_string = SupentryDisplayString(app, app.parent_dn)
-
     in_wrtattroids_fields_html = '\n'.join([
         app.form.hiddenFieldHTML('in_wrtattroids', at_name, '')
         for at_name in (
@@ -1342,7 +1342,7 @@ def w2l_modifyform(app, entry, msg='', invalid_attrs=None):
         INPUT_FORM_BEGIN_TMPL.format(
             text_heading=H1_MSG[app.command],
             text_msg=msg,
-            text_supentry=supentry_display_string,
+            text_supentry=superior_display_html(app, app.parent_dn),
             form_begin=app.begin_form(app.command, 'POST', enctype='multipart/form-data'),
             field_dn=app.form.hiddenFieldHTML('dn', app.dn, ''),
             field_currentformtype=app.form.hiddenFieldHTML('in_oft', input_formtype, ''),
@@ -1351,7 +1351,7 @@ def w2l_modifyform(app, entry, msg='', invalid_attrs=None):
 
     app.outf.write(
         '\n'.join((
-            app.form.hiddenFieldHTML('in_assertion', AssertionFilter(app, entry), ''),
+            app.form.hiddenFieldHTML('in_assertion', assertion_filter(app, entry), ''),
             '\n'.join([
                 app.form.hiddenFieldHTML('in_oldattrtypes', at_name, '')
                 for at_name in app.form.getInputValue('in_oldattrtypes', entry.keys())
