@@ -5,7 +5,7 @@ web2ldap.app.delete: delete one entry or several entries
 web2ldap - a web-based LDAP Client,
 see https://www.web2ldap.de for details
 
-(c) 1998-2020 by Michael Stroeder <michael@stroeder.com>
+(c) 1998-2021 by Michael Stroeder <michael@stroeder.com>
 
 This software is distributed under the terms of the
 Apache License Version 2.0 (Apache-2.0)
@@ -274,11 +274,11 @@ def del_singleentry_form(app):
 
 def del_subtree_form(app, scope):
     delete_scope_field = web2ldap.web.forms.Select(
-        'scope', u'Scope of delete operation', 1,
+        'scope', 'Scope of delete operation', 1,
         options=(
-            (str(ldap0.SCOPE_BASE), u'Only this entry'),
-            (str(ldap0.SCOPE_ONELEVEL), u'All entries below this entry (recursive)'),
-            (str(ldap0.SCOPE_SUBTREE), u'All entries including this entry (recursive)'),
+            (str(ldap0.SCOPE_BASE), 'Only this entry'),
+            (str(ldap0.SCOPE_ONELEVEL), 'All entries below this entry (recursive)'),
+            (str(ldap0.SCOPE_SUBTREE), 'All entries including this entry (recursive)'),
         ),
         default=str(scope),
     )
@@ -402,7 +402,7 @@ def w2l_delete(app):
                 form_begin=app.begin_form('delete', 'POST'),
                 inner_form=inner_form,
                 field_delete_ctrl=app.form.field['delete_ctrl'].input_html(default=delete_ctrl_oids),
-                field_hidden_dn=app.form.hiddenFieldHTML('dn', app.dn, u''),
+                field_hidden_dn=app.form.hiddenFieldHTML('dn', app.dn, ''),
             )
         )
         web2ldap.app.gui.footer(app)
@@ -413,7 +413,7 @@ def w2l_delete(app):
             'Canceled delete',
             '<p class="SuccessMessage">Canceled delete.</p>',
             main_menu_list=web2ldap.app.gui.main_menu(app),
-            context_menu_list=web2ldap.app.gui.ContextMenuSingleEntry(app)
+            context_menu_list=web2ldap.app.gui.context_menu_single_entry(app)
         )
         return
 
@@ -490,7 +490,7 @@ def w2l_delete(app):
                 ]),
             ),
             main_menu_list=web2ldap.app.gui.main_menu(app),
-            context_menu_list=web2ldap.app.gui.ContextMenuSingleEntry(app)
+            context_menu_list=web2ldap.app.gui.context_menu_single_entry(app)
         )
 
     elif scope == ldap0.SCOPE_BASE:
