@@ -5,7 +5,7 @@ web2ldap.app.gui: basic functions for GUI elements
 web2ldap - a web-based LDAP Client,
 see https://www.web2ldap.de for details
 
-(c) 1998-2020 by Michael Stroeder <michael@stroeder.com>
+(c) 1998-2021 by Michael Stroeder <michael@stroeder.com>
 
 This software is distributed under the terms of the
 Apache License Version 2.0 (Apache-2.0)
@@ -15,6 +15,7 @@ https://www.apache.org/licenses/LICENSE-2.0
 import time
 import os
 from hashlib import md5
+from typing import Sequence, Tuple, Union
 
 import ldap0
 import ldap0.ldapurl
@@ -23,21 +24,28 @@ import ldap0.filter
 from ldap0.dn import DNObj
 from ldap0.res import SearchResultEntry
 
+try:
+    import dns
+except ImportError:
+    dns_available = False
+else:
+    dns_available = True
+
 import web2ldapcnf
 
 import web2ldap.web.forms
 from web2ldap.web import escape_html
 import web2ldap.__about__
-import web2ldap.ldaputil
 import web2ldap.msbase
 import web2ldap.app.core
 import web2ldap.app.cnf
 import web2ldap.app.schema.syntaxes
 import web2ldap.app.searchform
 from web2ldap.msbase import GrabKeys
-import web2ldap.ldaputil
 from web2ldap.ldaputil import logdb_filter
 
+from web2ldap.log import logger
+logger.debug('dns_available = %r', dns_available)
 
 #---------------------------------------------------------------------------
 # Constants
@@ -62,7 +70,7 @@ HTML_FOOTER = """
 """
 
 
-def GetVariantFilename(pathname, variantlist):
+def get_variant_filename(pathname, variantlist):
     """
     returns variant filename
     """
@@ -74,10 +82,9 @@ def GetVariantFilename(pathname, variantlist):
             variant_filename = pathname
         else:
             variant_filename = '.'.join((pathname, v))
-        if not v in checked_set and os.path.isfile(variant_filename):
+        if v not in checked_set and os.path.isfile(variant_filename):
             break
-        else:
-            checked_set.add(v)
+        checked_set.add(v)
     else:
         variant_filename = pathname
     return variant_filename
@@ -88,7 +95,7 @@ def read_template(app, config_key, form_desc=u'', tmpl_filename=None):
         tmpl_filename = app.cfg_param(config_key, None)
     if not tmpl_filename:
         raise web2ldap.app.core.ErrorExit(u'No template specified for %s.' % (form_desc))
-    tmpl_filename = web2ldap.app.gui.GetVariantFilename(tmpl_filename, app.form.accept_language)
+    tmpl_filename = web2ldap.app.gui.get_variant_filename(tmpl_filename, app.form.accept_language)
     try:
         # Read template from file
         with open(tmpl_filename, 'rb') as tmpl_fileobj:
@@ -102,7 +109,11 @@ def dn_anchor_hash(dn):
     return str(md5(dn.encode('utf-8')).hexdigest())
 
 
-def ts2repr(time_divisors, ts_sep, ts_value: str) -> str:
+def ts2repr(
+        time_divisors: Sequence[Tuple[str, int]],
+        ts_sep: str,
+        ts_value: Union[str, bytes],
+    ) -> str:
     rest = int(ts_value)
     result = []
     for desc, divisor in time_divisors:
@@ -120,9 +131,9 @@ def repr2ts(time_divisors, ts_sep, value):
     l2 = [(int(v), d.strip()) for v, d in l1]
     time_divisors_dict = dict(time_divisors)
     result = 0
-    for value, desc in l2:
+    for val, desc in l2:
         try:
-            result += value*time_divisors_dict[desc]
+            result += val * time_divisors_dict[desc]
         except KeyError:
             raise ValueError
         else:
@@ -149,19 +160,20 @@ def command_div(
             (separator).join(commandlist),
             end_tag,
         )
-    return '' # command_div()
+    return ''
+    # end of command_div()
 
 
 def simple_main_menu(app):
     main_menu = [app.anchor('', 'Connect', [])]
     if web2ldap.app.handler.check_access(app.env, 'monitor'):
         main_menu.append(app.anchor('monitor', 'Monitor', []))
-    if web2ldap.app.handler.check_access(app.env, 'locate'):
+    if dns_available and web2ldap.app.handler.check_access(app.env, 'locate'):
         main_menu.append(app.anchor('locate', 'DNS lookup', []))
     return main_menu
 
 
-def ContextMenuSingleEntry(app, vcard_link=0, dds_link=0, entry_uuid=None):
+def context_menu_single_entry(app, vcard_link=0, dds_link=0, entry_uuid=None):
     """
     Output the context menu for a single entry
     """
@@ -285,7 +297,8 @@ def ContextMenuSingleEntry(app, vcard_link=0, dds_link=0, entry_uuid=None):
             title=u'Find connections of this user in monitor database',
         ))
 
-    return result # ContextMenuSingleEntry()
+    return result
+    # end of context_menu_single_entry()
 
 
 def display_authz_dn(app, who=None, entry=None):
@@ -325,8 +338,8 @@ def display_authz_dn(app, who=None, entry=None):
                         pass
     else:
         result = app.form.utf2display(who)
-    return result # display_authz_dn()
-
+    return result
+    # end of display_authz_dn()
 
 
 def main_menu(app):
@@ -408,7 +421,8 @@ def main_menu(app):
 
         cl.append(app.anchor('', 'Connect', (), title=u'New connection to LDAP server'))
 
-    return cl # main_menu()
+    return cl
+    # end of main_menu()
 
 
 def dit_navigation(app):
@@ -428,7 +442,8 @@ def dit_navigation(app):
             title=u'Jump to root DSE',
         )
     )
-    return result # dit_navigation()
+    return result
+    # end of dit_navigation()
 
 
 def top_section(
@@ -489,7 +504,6 @@ def top_section(
         template_dict['who'] = display_authz_dn(app)
 
     app.outf.write(top_template_str.format(**template_dict))
-
     # end of top_section()
 
 
@@ -552,6 +566,7 @@ def attrtype_select_field(
     )
     attr_select.charset = app.form.accept_charset
     return attr_select
+    # end of attrtype_select_field()
 
 
 def gen_headers(content_type, charset, more_headers=None):
@@ -567,7 +582,8 @@ def gen_headers(content_type, charset, more_headers=None):
     for h, v in web2ldapcnf.http_headers.items():
         headers.append((h, v))
     headers.extend(more_headers or [])
-    return headers # gen_headers()
+    return headers
+    # end of gen_headers()
 
 
 def Header(app, content_type, charset, more_headers=None):
@@ -584,7 +600,8 @@ def Header(app, content_type, charset, more_headers=None):
        'Strict-Transport-Security' not in web2ldapcnf.http_headers:
         headers.append(('Strict-Transport-Security', 'max-age=15768000 ; includeSubDomains'))
     app.outf.set_headers(headers)
-    return headers # Header()
+    return headers
+    # end of Header()
 
 
 def footer(app):
@@ -653,7 +670,7 @@ def search_root_field(
     )
     srf.charset = app.form.accept_charset
     return srf
-    # search_root_field()
+    # end of search_root_field()
 
 
 def invalid_syntax_message(app, invalid_attrs):
