@@ -4,7 +4,7 @@
 web2ldap - a web-based LDAP Client,
 see https://www.web2ldap.de for details
 
-(c) 1998-2020 by Michael Stroeder <michael@stroeder.com>
+(c) 1998-2021 by Michael Stroeder <michael@stroeder.com>
 
 This software is distributed under the terms of the
 Apache License Version 2.0 (Apache-2.0)
@@ -37,7 +37,6 @@ import web2ldap.web.session
 from web2ldap.web.helper import get_remote_ip
 import web2ldap.__about__
 import web2ldap.ldaputil
-import web2ldap.ldaputil.dns
 import web2ldap.ldapsession
 from web2ldap.ldaputil.extldapurl import ExtendedLDAPUrl
 from web2ldap.ldapsession import LDAPSession
@@ -69,12 +68,14 @@ import web2ldap.app.bulkmod
 import web2ldap.app.srvrr
 import web2ldap.app.schema.viewer
 import web2ldap.app.metrics
-from web2ldap.app.gui import exception_message
+from web2ldap.app.gui import exception_message, dns_available
 from web2ldap.app.form import Web2LDAPForm
 from web2ldap.app.session import session_store
 from web2ldap.app.schema.syntaxes import syntax_registry
 from web2ldap.ldaputil import AD_LDAP49_ERROR_CODES, AD_LDAP49_ERROR_PREFIX
 from web2ldap.app.core import ErrorExit
+if dns_available:
+    from web2ldap.ldaputil.dns import dc_dn_lookup
 
 SCOPE2COMMAND = {
     None:'search',
@@ -142,9 +143,9 @@ syntax_registry.check()
 
 def check_access(env, command):
     """
-    simple access control based on REMOTE_ADDR
+    simple access control based on client IP address
     """
-    remote_addr = ip_address(env['REMOTE_ADDR'])
+    remote_addr = ip_address(env[web2ldapcnf.httpenv_remote_addr.split(',')[-1].strip()])
     access_allowed = web2ldapcnf.access_allowed.get(
         command,
         web2ldapcnf.access_allowed['_']
@@ -166,6 +167,7 @@ class AppHandler(LogHelper):
         self.inf = env['wsgi.input']
         self.outf = outf
         self.env = env
+        self.env.update(web2ldapcnf.httpenv_override)
         self.script_name = self.env['SCRIPT_NAME']
         self.command, self.sid = self.path_info(env)
         self.form = None
@@ -176,6 +178,7 @@ class AppHandler(LogHelper):
         self.ldap_url = None
         self.schema = None
         self.cfg_key = None
+        self._session_store = session_store()
         # initialize some more if query string is an LDAP URL
         if is_ldapurl(self.query_string):
             self.ldap_url = ExtendedLDAPUrl(self.query_string)
@@ -469,14 +472,14 @@ class AppHandler(LogHelper):
         """
         create new session
         """
-        self.sid = session_store.new(self.env)
+        self.sid = self._session_store.new(self.env)
         self.ls = LDAPSession(
             get_remote_ip(self.env),
             web2ldapcnf.ldap_trace_level,
             web2ldapcnf.ldap_cache_ttl,
         )
         self.ls.cookie = self.form.set_cookie(str(id(self.ls)))
-        session_store.save(self.sid, self.ls)
+        self._session_store.save(self.sid, self.ls)
         # end of _get_session()
 
     def _get_session(self):
@@ -486,10 +489,10 @@ class AppHandler(LogHelper):
         if self.sid:
             # Session ID given => try to restore old session
             try:
-                last_session_timestamp, _ = session_store.sessiondict[self.sid]
+                last_session_timestamp, _ = self._session_store.sessiondict[self.sid]
             except KeyError:
                 pass
-            self.ls = session_store.retrieveSession(self.sid, self.env)
+            self.ls = self._session_store.retrieveSession(self.sid, self.env)
             if not isinstance(self.ls, LDAPSession):
                 raise web2ldap.app.session.InvalidSessionInstance()
             if self.ls.cookie:
@@ -503,7 +506,7 @@ class AppHandler(LogHelper):
             if web2ldapcnf.session_paranoid and \
                self.current_access_time-last_session_timestamp > web2ldapcnf.session_paranoid:
                 # Store session with new session ID
-                self.sid = session_store.rename(self.sid, self.env)
+                self.sid = self._session_store.rename(self.sid, self.env)
         else:
             self.ls = None
         # end of _get_session()
@@ -512,7 +515,7 @@ class AppHandler(LogHelper):
         """
         delete the current session
         """
-        session_store.delete(self.sid)
+        self._session_store.delete(self.sid)
         del self.ls
         self.sid = self.ls = None
         # end of _del_session()
@@ -526,14 +529,14 @@ class AppHandler(LogHelper):
         except IndexError:
             return
         try:
-            old_ls = session_store.retrieveSession(del_sid, self.env)
+            old_ls = self._session_store.retrieveSession(del_sid, self.env)
         except web2ldap.web.session.SessionException:
             pass
         else:
             # Remove session cookie
             self.form.unset_cookie(old_ls.cookie)
         # Explicitly remove old session
-        session_store.delete(del_sid)
+        self._session_store.delete(del_sid)
         # end of _handle_delsid()
 
     def _get_ldapconn_params(self):
@@ -717,7 +720,7 @@ class AppHandler(LogHelper):
                 self.log(
                     logging.WARN,
                     'Access denied from %r to command %r',
-                    self.env['REMOTE_ADDR'],
+                    self.env[web2ldapcnf.httpenv_remote_addr],
                     self.command,
                 )
                 raise ErrorExit(u'Access denied.')
@@ -733,7 +736,7 @@ class AppHandler(LogHelper):
                 # Remove session cookie
                 self.form.unset_cookie(self.ls.cookie)
                 # Explicitly remove old session
-                session_store.delete(self.sid)
+                self._session_store.delete(self.sid)
                 self.sid = None
                 # Redirect to start page to avoid people bookmarking disconnect URL
                 self.url_redirect(u'Disconnecting...', refresh_time=0)
@@ -752,19 +755,22 @@ class AppHandler(LogHelper):
             # Connect to LDAP server
             #-------------------------------------------------
 
-            if self.ldap_url.hostport == '' and \
-               self.ldap_url.urlscheme == 'ldap' and \
-               (self.ls is None or self.ls.uri is None):
+            if (
+                    dns_available
+                    and self.ldap_url.hostport == ''
+                    and self.ldap_url.urlscheme == 'ldap'
+                    and (self.ls is None or self.ls.uri is None)
+                ):
                 # Force a SRV RR lookup for dc-style DNs,
                 # create list of URLs to connect to
-                dns_srv_rrs = web2ldap.ldaputil.dns.dc_dn_lookup(self.dn)
+                dns_srv_rrs = dc_dn_lookup(self.dn)
                 init_uri_list = [
                     ExtendedLDAPUrl(urlscheme='ldap', hostport=host, dn=self.dn).connect_uri()
                     for host in dns_srv_rrs
                 ]
                 if not init_uri_list:
                     # No host specified in user's input
-                    session_store.delete(self.sid)
+                    self._session_store.delete(self.sid)
                     self.sid = None
                     web2ldap.app.connect.w2l_connect(
                         self,
@@ -776,10 +782,7 @@ class AppHandler(LogHelper):
                     init_uri = init_uri_list[0]
                 else:
                     # more than one possible servers => let user choose one
-                    web2ldap.app.srvrr.w2l_chasesrvrecord(
-                        self,
-                        init_uri_list
-                    )
+                    web2ldap.app.srvrr.w2l_chasesrvrecord(self, init_uri_list)
                     return
             elif self.ldap_url.hostport is not None:
                 init_uri = str(self.ldap_url.connect_uri()[:])
@@ -813,7 +816,7 @@ class AppHandler(LogHelper):
                 self.ls.l.timeout = self.cfg_param('timeout', 60)
                 # Store session data in case anything goes wrong after here
                 # to give the exception handler a good chance
-                session_store.save(self.sid, self.ls)
+                self._session_store.save(self.sid, self.ls)
 
             # from here the code assumes that there is a valid LDAPSession instance
             if self.ls is None:
@@ -822,7 +825,7 @@ class AppHandler(LogHelper):
                 return
 
             if self.ls.uri is None:
-                session_store.delete(self.sid)
+                self._session_store.delete(self.sid)
                 self.sid = None
                 web2ldap.app.connect.w2l_connect(
                     self,
@@ -833,7 +836,7 @@ class AppHandler(LogHelper):
 
             # Store session data in case anything goes wrong after here
             # to give the exception handler a good chance
-            session_store.save(self.sid, self.ls)
+            self._session_store.save(self.sid, self.ls)
             self.dn = self.dn
 
             login_mech = self.form.getInputValue(
@@ -856,8 +859,13 @@ class AppHandler(LogHelper):
                 return
 
             if (
-                    (who is not None and cred is not None) or
-                    (login_mech is not None and login_mech.encode('ascii') in ldap0.sasl.SASL_NONINTERACTIVE_MECHS)
+                    (who is not None and cred is not None)
+                    or
+                    (
+                        login_mech is not None
+                        and
+                        login_mech.encode('ascii') in ldap0.sasl.SASL_NONINTERACTIVE_MECHS
+                    )
                 ):
                 self.dn = self.dn
                 # real bind operation
@@ -900,7 +908,7 @@ class AppHandler(LogHelper):
                 return
             # Store session data in case anything goes wrong after here
             # to give the exception handler a good chance
-            session_store.save(self.sid, self.ls)
+            self._session_store.save(self.sid, self.ls)
 
             # trigger update of various DN-related class properties
             self.dn = self.dn
@@ -914,7 +922,7 @@ class AppHandler(LogHelper):
                 self.dispatch()
             else:
                 # Store current session
-                session_store.save(self.sid, self.ls)
+                self._session_store.save(self.sid, self.ls)
 
         except web2ldap.web.forms.FormException as form_error:
             log_exception(self.env, self.ls, self.dn, web2ldapcnf.log_error_details)
@@ -928,7 +936,7 @@ class AppHandler(LogHelper):
 
         except ldap0.SERVER_DOWN as err:
             # Server is down and reconnecting impossible => remove session
-            session_store.delete(self.sid)
+            self._session_store.delete(self.sid)
             self.sid = None
             # Redirect to entry page
             web2ldap.app.connect.w2l_connect(
@@ -942,13 +950,14 @@ class AppHandler(LogHelper):
 
         except ldap0.NO_SUCH_OBJECT as ldap_err:
 
-            # first try to lookup dc-style DN via DNS
-            host_list = web2ldap.ldaputil.dns.dc_dn_lookup(self.dn)
-            self.log(logging.DEBUG, 'host_list = %r', host_list)
-            if host_list and ExtendedLDAPUrl(self.ls.uri).hostport not in host_list:
-                # Found LDAP server for this naming context via DNS SRV RR
-                web2ldap.app.srvrr.w2l_chasesrvrecord(self, host_list)
-                return
+            if dns_available:
+                # first try to lookup dc-style DN via DNS
+                host_list = dc_dn_lookup(self.dn)
+                self.log(logging.DEBUG, 'host_list = %r', host_list)
+                if host_list and ExtendedLDAPUrl(self.ls.uri).hostport not in host_list:
+                    # Found LDAP server for this naming context via DNS SRV RR
+                    web2ldap.app.srvrr.w2l_chasesrvrecord(self, host_list)
+                    return
 
             # Normal error handling
             log_exception(self.env, self.ls, self.dn, web2ldapcnf.log_error_details)
@@ -1024,7 +1033,7 @@ class AppHandler(LogHelper):
 
         except PasswordPolicyException as err:
             # Setup what's required for executing command 'passwd'
-            self.dn = (self.ls.l.whoami_s()[3:] or err.who).decode(self.ls.charset)
+            self.dn = self.ls.l.get_whoami_dn() or err.who
             # Output the change password form
             web2ldap.app.passwd.passwd_form(
                 self,
@@ -1078,8 +1087,12 @@ class AppHandler(LogHelper):
             self.simple_msg(u'Too many web sessions! Try later...')
 
         except web2ldap.web.session.SessionException:
-            log_exception(self.env, self.ls, self.dn, web2ldapcnf.log_error_details)
-            self.url_redirect(u'Session handling error.')
+            if self.command == 'disconnect':
+                # Probably already disconnected => ignore exception and redirect to start page
+                self.url_redirect(u'Disconnecting...', refresh_time=0)
+            else:
+                log_exception(self.env, self.ls, self.dn, web2ldapcnf.log_error_details)
+                self.url_redirect(u'Session handling error.')
 
         except Exception:
             if hasattr(self, 'ls'):
