@@ -9,7 +9,7 @@ web2ldap plugin classes for
 import re
 import time
 import socket
-from typing import List
+from typing import Dict, List, Optional
 
 # from ldap0 package
 import ldap0
@@ -25,7 +25,7 @@ from ldap0.base import decode_list
 import web2ldapcnf
 
 from web2ldap.log import logger
-from web2ldap.web.forms import HiddenInput
+import web2ldap.web.forms
 import web2ldap.ldaputil
 import web2ldap.app.searchform
 import web2ldap.app.plugins.inetorgperson
@@ -135,7 +135,7 @@ class AEObjectMixIn:
         return res
 
     def _get_zone_dn(self) -> str:
-        return str(self.dn.slice(None, -len(DNObj.from_str(self._app.naming_context))-1))
+        return str(self.dn.slice(-len(DNObj.from_str(self._app.naming_context))-1, None))
 
     def _get_zone_name(self) -> str:
         return self.dn[-len(DNObj.from_str(self._app.naming_context))-1][0][1]
@@ -178,8 +178,8 @@ class AEHomeDirectory(HomeDirectory):
             prefix = self.homeDirectoryPrefixes[0]
         return [self._app.ls.uc_encode('/'.join((prefix, uid)))[0]]
 
-    def formField(self) -> str:
-        input_field = HiddenInput(
+    def formField(self) -> web2ldap.web.forms.Field:
+        input_field = web2ldap.web.forms.HiddenInput(
             self._at,
             ': '.join([self._at, self.desc]),
             self.maxLen,
@@ -205,8 +205,8 @@ class AEUIDNumber(UidNumber):
     def transmute(self, attrValues: List[bytes]) -> List[bytes]:
         return self._entry.get('gidNumber', [b''])
 
-    def formField(self) -> str:
-        input_field = HiddenInput(
+    def formField(self) -> web2ldap.web.forms.Field:
+        input_field = web2ldap.web.forms.HiddenInput(
             self._at,
             ': '.join([self._at, self.desc]),
             self.maxLen, self.maxValues, None,
@@ -277,7 +277,7 @@ class AEGIDNumber(GidNumber):
     def formValue(self) -> str:
         return Integer.formValue(self)
 
-    def formField(self) -> str:
+    def formField(self) -> web2ldap.web.forms.Field:
         return Integer.formField(self)
 
 syntax_registry.reg_at(
@@ -347,8 +347,8 @@ class AEUserUid(AEUid):
             form_value = self._gen_uid()
         return form_value
 
-    def formField(self) -> str:
-        return HiddenInput(
+    def formField(self) -> web2ldap.web.forms.Field:
+        return web2ldap.web.forms.HiddenInput(
             self._at,
             ': '.join([self._at, self.desc]),
             self.maxLen, self.maxValues, None,
@@ -506,7 +506,7 @@ class AEGroupMember(DerefDynamicDNSelectList, AEObjectMixIn):
         else:
             srv_ctrls = None
         # Use the existing LDAP connection as current user
-        attr_value_dict = SelectList._get_attr_value_dict(self)
+        attr_value_dict: Dict[str, str] = SelectList._get_attr_value_dict(self)
         member_filter = self._filterstr()
         try:
             ldap_result = self._app.ls.l.search_s(
@@ -635,8 +635,8 @@ class AEMemberUid(MemberUID, AEObjectMixIn):
     def formValue(self) -> str:
         return ''
 
-    def formField(self) -> str:
-        input_field = HiddenInput(
+    def formField(self) -> web2ldap.web.forms.Field:
+        input_field = web2ldap.web.forms.HiddenInput(
             self._at,
             ': '.join([self._at, self.desc]),
             self.maxLen, self.maxValues, None,
@@ -830,18 +830,26 @@ class AESameZoneObject(DerefDynamicDNSelectList, AEObjectMixIn):
         return self._get_zone_dn()
 
 
-class AESrvGroup(AESameZoneObject):
+class AESrvGroupDN(AEGroupDN):
+    oid: str = 'AESrvGroupDN-oid'
+    desc: str = 'AE-DIR: DN of a referenced aeSrvGroup entry'
+    ldap_url = 'ldap:///_?cn?sub?(&(objectClass=aeSrvGroup)(aeStatus=0))'
+    ref_attrs = DerefDynamicDNSelectList.ref_attrs
+
+
+class AESrvGroup(AESrvGroupDN, AESameZoneObject):
     oid: str = 'AESrvGroup-oid'
-    desc: str = 'AE-DIR: DN of referenced aeSrvGroup entry'
+    desc: str = 'AE-DIR: DN of supplemental aeSrvGroup entry'
     ldap_url = 'ldap:///_?cn?sub?(&(objectClass=aeSrvGroup)(aeStatus=0)(!(aeProxyFor=*)))'
 
     def _filterstr(self):
-        filter_str = self.lu_obj.filterstr or '(objectClass=*)'
+        filter_str = self.lu_obj.filterstr or '(objectClass=aeSrvGroup)'
         return '(&%s(!(entryDN=%s)))' % (
             filter_str,
             ldap0.filter.escape_str(str(self.dn.parent())),
         )
 
+
 syntax_registry.reg_at(
     AESrvGroup.oid, [
         AE_OID_PREFIX+'.4.27', # aeSrvGroup
@@ -849,7 +857,7 @@ syntax_registry.reg_at(
 )
 
 
-class AERequires(DerefDynamicDNSelectList):
+class AERequires(AESrvGroupDN):
     oid: str = 'AERequires-oid'
     desc: str = 'AE-DIR: DN of required aeSrvGroup'
     ldap_url = 'ldap:///_?cn?sub?(&(objectClass=aeSrvGroup)(aeStatus=0))'
@@ -863,12 +871,12 @@ class AERequires(DerefDynamicDNSelectList):
 
 syntax_registry.reg_at(
     AERequires.oid, [
-        AE_OID_PREFIX+'.4.48', # aeSrvGroup
+        AE_OID_PREFIX+'.4.48', # aeRequires
     ]
 )
 
 
-class AEProxyFor(AESameZoneObject, AEObjectMixIn):
+class AEProxyFor(AESrvGroupDN, AESameZoneObject):
     oid: str = 'AEProxyFor-oid'
     desc: str = 'AE-DIR: DN of referenced aeSrvGroup entry this is proxy for'
     ldap_url = 'ldap:///_?cn?sub?(&(objectClass=aeSrvGroup)(aeStatus=0)(!(aeProxyFor=*)))'
@@ -877,7 +885,7 @@ class AEProxyFor(AESameZoneObject, AEObjectMixIn):
         filter_str = self.lu_obj.filterstr or '(objectClass=*)'
         return '(&%s(!(entryDN=%s)))' % (
             filter_str,
-            self._dn,
+            ldap0.filter.escape_str(self._dn),
         )
 
 syntax_registry.reg_at(
@@ -930,6 +938,22 @@ class AEEntryDNAEUser(DistinguishedName):
 
     def _additional_links(self):
         res = DistinguishedName._additional_links(self)
+        res.append(self._app.anchor(
+            'searchform', 'Created/Modified',
+            (
+                ('dn', self._dn),
+                ('search_root', str(self._app.naming_context)),
+                ('searchform_mode', 'adv'),
+                ('search_mode', '(|%s)'),
+                ('search_attr', 'creatorsName'),
+                ('search_option', web2ldap.app.searchform.SEARCH_OPT_IS_EQUAL),
+                ('search_string', self.av_u),
+                ('search_attr', 'modifiersName'),
+                ('search_option', web2ldap.app.searchform.SEARCH_OPT_IS_EQUAL),
+                ('search_string', self.av_u),
+            ),
+            title='Search entries created or modified by %s' % (self.av_u),
+        ))
         if self._app.audit_context:
             res.append(self._app.anchor(
                 'search', 'Activity',
@@ -953,6 +977,7 @@ syntax_registry.reg_at(
     ],
     structural_oc_oids=[
         AE_USER_OID, # aeUser
+        AE_SERVICE_OID, # aeService
     ],
 )
 
@@ -1025,7 +1050,7 @@ class AEEntryDNAEZone(DistinguishedName):
                     ('search_option', web2ldap.app.searchform.SEARCH_OPT_DN_SUBTREE),
                     ('search_string', self.av_u),
                 ),
-                title=u'Search all audit log entries for sub-tree %s' % (self.av_u),
+                title='Search all audit log entries for sub-tree %s' % (self.av_u),
             ))
             res.append(self._app.anchor(
                 'search', 'Audit writes',
@@ -1039,7 +1064,7 @@ class AEEntryDNAEZone(DistinguishedName):
                     ('search_option', web2ldap.app.searchform.SEARCH_OPT_DN_SUBTREE),
                     ('search_string', self.av_u),
                 ),
-                title=u'Search audit log entries for write operation within sub-tree %s' % (
+                title='Search audit log entries for write operation within sub-tree %s' % (
                     self.av_u
                 ),
             ))
@@ -1117,7 +1142,7 @@ class AEEntryDNAEGroup(GroupEntryDN):
                 ('search_option', web2ldap.app.searchform.SEARCH_OPT_IS_EQUAL),
                 ('search_string', '%'+self._entry['cn'][0].decode(self._app.ls.charset)),
             ),
-            title=u'Search for SUDO rules\napplicable with this user group',
+            title='Search for SUDO rules\napplicable with this user group',
         ))
         return res
 
@@ -1161,7 +1186,7 @@ class AEEntryDNAESrvGroup(DistinguishedName):
                         ).format(self.av_u)
                     ),
                 ),
-                title=u'Search all service and host entries which are member in this service/host group {0}'.format(self.av_u),
+                title='Search all service and host entries which are member in this service/host group {0}'.format(self.av_u),
             )
         )
         return res
@@ -1218,6 +1243,7 @@ class AELocation(DerefDynamicDNSelectList):
     input_fallback = False # no fallback to normal input field
     ldap_url = 'ldap:///_?displayName?sub?(&(objectClass=aeLocation)(aeStatus=0))'
     ref_attrs = AEEntryDNAELocation.ref_attrs
+    desc_sep: str = '<br>'
 
 syntax_registry.reg_at(
     AELocation.oid, [
@@ -1251,6 +1277,7 @@ class AEDept(DerefDynamicDNSelectList):
     input_fallback = False # no fallback to normal input field
     ldap_url = 'ldap:///_?displayName?sub?(&(objectClass=aeDept)(aeStatus=0))'
     ref_attrs = AEEntryDNAEDept.ref_attrs
+    desc_sep: str = '<br>'
 
 syntax_registry.reg_at(
     AEDept.oid, [
@@ -1266,6 +1293,7 @@ class AEOwner(DerefDynamicDNSelectList):
     ref_attrs = (
         ('aeOwner', 'Devices', None, 'aeDevice', 'Search all devices (aeDevice entries) assigned to same owner.'),
     )
+    desc_sep: str = '<br>'
 
 syntax_registry.reg_at(
     AEOwner.oid, [
@@ -1281,6 +1309,7 @@ class AEPerson(DerefDynamicDNSelectList, AEObjectMixIn):
     ref_attrs = (
         ('aePerson', 'Users', None, 'aeUser', 'Search all personal AE-DIR user accounts (aeUser entries) of this person.'),
     )
+    desc_sep: str = '<br>'
     ae_status_map = {
         -1: (-1, 0),
         0: (0,),
@@ -1343,6 +1372,7 @@ class AEManager(DerefDynamicDNSelectList):
     desc: str = 'AE-DIR: Manager responsible for a person/department'
     input_fallback = False # no fallback to normal input field
     ldap_url = 'ldap:///_?displayName?sub?(&(objectClass=aePerson)(aeStatus=0))'
+    desc_sep: str = '<br>'
 
 syntax_registry.reg_at(
     AEManager.oid, [
@@ -1357,10 +1387,10 @@ syntax_registry.reg_at(
 
 class AEDerefAttribute(DirectoryString):
     oid: str = 'AEDerefAttribute-oid'
-    maxValues = 1
-    deref_object_class = None
-    deref_attribute_type = None
-    deref_filter_tmpl = '(&(objectClass={deref_object_class})(aeStatus<=0)({attribute_type}=*))'
+    maxValues: int = 1
+    deref_object_class: Optional[str] = None
+    deref_attribute_type: Optional[str] = None
+    deref_filter_tmpl: str = '(&(objectClass={deref_object_class})(aeStatus<=0)({attribute_type}=*))'
 
     def _read_person_attr(self):
         try:
@@ -1392,8 +1422,8 @@ class AEDerefAttribute(DirectoryString):
     def formValue(self) -> str:
         return ''
 
-    def formField(self) -> str:
-        input_field = HiddenInput(
+    def formField(self) -> web2ldap.web.forms.Field:
+        input_field = web2ldap.web.forms.HiddenInput(
             self._at,
             ': '.join([self._at, self.desc]),
             self.maxLen, self.maxValues, None,
@@ -1447,10 +1477,13 @@ class AEUserMailaddress(AEPersonAttribute, SelectList):
     html_tmpl = RFC822Address.html_tmpl
     maxValues = 1
     input_fallback = False
-    simpleSanitizers = AEMailLocalAddress.simpleSanitizers
+    simpleSanitizers = (
+        bytes.strip,
+        bytes.lower,
+    )
 
     def _get_attr_value_dict(self):
-        attr_value_dict = {
+        attr_value_dict: Dict[str, str] = {
             '': '-/-',
         }
         attr_value_dict.update([
@@ -1484,7 +1517,7 @@ class AEUserMailaddress(AEPersonAttribute, SelectList):
             attrValues = AEPersonAttribute.transmute(self, attrValues)
         return attrValues
 
-    def formField(self) -> str:
+    def formField(self) -> web2ldap.web.forms.Field:
         if self._is_mail_account():
             return SelectList.formField(self)
         return AEPersonAttribute.formField(self)
@@ -1509,7 +1542,7 @@ class AEPersonMailaddress(DynamicValueSelectList, RFC822Address):
     def _validate(self, attrValue: bytes) -> bool:
         if not RFC822Address._validate(self, attrValue):
             return False
-        attr_value_dict = self._get_attr_value_dict()
+        attr_value_dict: Dict[str, str] = self._get_attr_value_dict()
         if (
                 not attr_value_dict
                 or (
@@ -1568,7 +1601,7 @@ class AEHostname(DNSDomain):
             return False
         if self.host_lookup:
             try:
-                ip_addr = socket.gethostbyname(attrValue)
+                ip_addr = socket.gethostbyname(self._app.ls.uc_decode(attrValue)[0])
             except (socket.gaierror, socket.herror):
                 return False
             if self.host_lookup >= 2:
@@ -1586,7 +1619,7 @@ class AEHostname(DNSDomain):
             attr_value.lower().strip()
             if self.host_lookup:
                 try:
-                    ip_addr = socket.gethostbyname(attr_value)
+                    ip_addr = socket.gethostbyname(self._app.ls.uc_decode(attr_value)[0])
                     reverse_hostname = socket.gethostbyaddr(ip_addr)[0]
                 except (socket.gaierror, socket.herror):
                     pass
@@ -1702,8 +1735,8 @@ class AEUniqueIdentifier(DirectoryString):
             return [self.gen_template.format(timestamp=time.time()).encode(self._app.ls.charset)]
         return attrValues
 
-    def formField(self) -> str:
-        input_field = HiddenInput(
+    def formField(self) -> web2ldap.web.forms.Field:
+        input_field = web2ldap.web.forms.HiddenInput(
             self._at,
             ': '.join([self._at, self.desc]),
             self.maxLen, self.maxValues, None,
@@ -1786,10 +1819,10 @@ class AECommonNameAEHost(AECommonName):
 
     def transmute(self, attrValues: List[bytes]) -> List[bytes]:
         if self.derive_from_host:
-            return {
+            return list({
                 b'.'.join(av.strip().lower().split(b'.')[self.host_begin_item:self.host_end_item])
                 for av in self._entry['host']
-            }
+            })
         return attrValues
 
 syntax_registry.reg_at(
@@ -1824,7 +1857,7 @@ class AEZonePrefixCommonName(AECommonName, AEObjectMixIn):
             zone_cn = self._get_zone_name()
             result = (
                 zone_cn and
-                (zone_cn == 'pub' or attrValue.decode(self._app.ls.charset).startswith(zone_cn+u'-'))
+                (zone_cn == 'pub' or attrValue.decode(self._app.ls.charset).startswith(zone_cn+'-'))
             )
         return result
 
@@ -1833,10 +1866,10 @@ class AEZonePrefixCommonName(AECommonName, AEObjectMixIn):
         zone_cn = self._get_zone_name()
         if zone_cn:
             if not self._av:
-                result = zone_cn+u'-'
+                result = zone_cn+'-'
             elif self._av_u in self.special_names:
                 result = '-'.join((zone_cn, self.av_u))
-        return result # formValue()
+        return result
 
 
 class AECommonNameAEGroup(AEZonePrefixCommonName):
@@ -1882,7 +1915,7 @@ class AECommonNameAETag(AEZonePrefixCommonName):
                     ('search_option', web2ldap.app.searchform.SEARCH_OPT_IS_EQUAL),
                     ('search_string', self.av_u),
                 ),
-                title=u'Search all entries tagged with this tag',
+                title='Search all entries tagged with this tag',
             )
         else:
             search_anchor = ''
@@ -1982,7 +2015,7 @@ syntax_registry.reg_at(
 class AEStatus(SelectList, Integer):
     oid: str = 'AEStatus-oid'
     desc: str = 'AE-DIR: Status of object'
-    attr_value_dict = {
+    attr_value_dict: Dict[str, str] = {
         '-1': 'requested',
         '0': 'active',
         '1': 'deactivated',
@@ -2020,7 +2053,7 @@ class AEStatus(SelectList, Integer):
         try:
             ae_not_before = time.strptime(self._entry['aeNotBefore'][0].decode('ascii'), '%Y%m%d%H%M%SZ')
         except (KeyError, IndexError, ValueError):
-            ae_not_before = None
+            pass
         else:
             if ae_status == 0 and current_time < ae_not_before:
                 ae_status = -1
@@ -2054,7 +2087,7 @@ syntax_registry.reg_at(
 class AEExpiryStatus(SelectList):
     oid: str = 'AEExpiryStatus-oid'
     desc: str = 'AE-DIR: Expiry status of object'
-    attr_value_dict = {
+    attr_value_dict: Dict[str, str] = {
         '-/-': '',
         '1': 'deactivated',
         '2': 'archived',
@@ -2193,8 +2226,8 @@ class AERFC822MailMember(DynamicValueSelectList, AEObjectMixIn):
             mail_addresses.extend(res.entry_as['mail'])
         return sorted(mail_addresses)
 
-    def formField(self) -> str:
-        input_field = HiddenInput(
+    def formField(self) -> web2ldap.web.forms.Field:
+        input_field = web2ldap.web.forms.HiddenInput(
             self._at,
             ': '.join([self._at, self.desc]),
             self.maxLen, self.maxValues, None,
@@ -2239,8 +2272,8 @@ class AESudoHost(IA5String):
     def transmute(self, attrValues: List[bytes]) -> List[bytes]:
         return [b'ALL']
 
-    def formField(self) -> str:
-        input_field = HiddenInput(
+    def formField(self) -> web2ldap.web.forms.Field:
+        input_field = web2ldap.web.forms.HiddenInput(
             self._at,
             ': '.join([self._at, self.desc]),
             self.maxLen, self.maxValues, None,
@@ -2262,7 +2295,7 @@ syntax_registry.reg_at(
 class AELoginShell(Shell):
     oid: str = 'AELoginShell-oid'
     desc: str = 'AE-DIR: Login shell for POSIX users'
-    attr_value_dict = {
+    attr_value_dict: Dict[str, str] = {
         '/bin/bash': '/bin/bash',
         '/bin/true': '/bin/true',
         '/bin/false': '/bin/false',
@@ -2310,7 +2343,7 @@ syntax_registry.reg_at(
 class AESSHPermissions(SelectList):
     oid: str = 'AESSHPermissions-oid'
     desc: str = 'AE-DIR: Status of object'
-    attr_value_dict = {
+    attr_value_dict: Dict[str, str] = {
         'pty': 'PTY allocation',
         'X11-forwarding': 'X11 forwarding',
         'agent-forwarding': 'Key agent forwarding',
@@ -2358,7 +2391,7 @@ syntax_registry.reg_at(
 class AEChildClasses(SelectList):
     oid = 'AEChildClasses-oid'
     desc = 'AE-DIR: Structural object classes allowed to be added in child entries'
-    attr_value_dict = {
+    attr_value_dict: Dict[str, str] = {
         '-/-': '',
         'aeAuthcToken': 'Authentication Token (aeAuthcToken)',
         'aeContact': 'Contact (aeContact)',
