@@ -5,6 +5,7 @@ web2ldap plugin classes for OpenLDAP
 
 import re
 import binascii
+from typing import Dict
 
 from pyasn1.codec.ber import decoder as ber_decoder
 
@@ -93,10 +94,10 @@ syntax_registry.reg_at(
 class OlcSubordinate(SelectList):
     oid: str = 'OlcSubordinate-oid'
     desc: str = 'Indicates whether backend is subordinate'
-    attr_value_dict = {
-        u'': u'-/- (FALSE)',
-        u'TRUE': u'TRUE',
-        u'advertise': u'advertise',
+    attr_value_dict: Dict[str, str] = {
+        '': '-/- (FALSE)',
+        'TRUE': 'TRUE',
+        'advertise': 'advertise',
     }
 
 syntax_registry.reg_at(
@@ -160,7 +161,7 @@ class OlcSyncRepl(OlcMultilineText, LDAPUrl):
     def display(self, valueindex=0, commandbutton=False) -> str:
         if not commandbutton or not self._av:
             return OlcMultilineText.display(self, valueindex, commandbutton)
-        srd = ldap0.openldap.SyncReplDesc(self._av)
+        srd = ldap0.openldap.SyncReplDesc(self.av_u)
         return ' '.join((
             OlcMultilineText.display(self, valueindex, commandbutton),
             web2ldap.app.gui.ldap_url_anchor(
@@ -220,11 +221,11 @@ syntax_registry.reg_at(
 class OlcMemberOfDangling(SelectList):
     oid: str = 'OlcMemberOfDangling-oid'
     desc: str = 'Behavior in case of dangling references during modification'
-    attr_value_dict = {
-        u'': u'-/-',
-        u'ignore': u'ignore',
-        u'drop': u'drop',
-        u'error': u'error',
+    attr_value_dict: Dict[str, str] = {
+        '': '-/-',
+        'ignore': 'ignore',
+        'drop': 'drop',
+        'error': 'error',
     }
 
 syntax_registry.reg_at(
@@ -261,7 +262,7 @@ class AuditContext(NamingContexts):
                         ('dn', self.av_u),
                         ('scope', str(ldap0.SCOPE_ONELEVEL)),
                     ],
-                    title=u'Go to search form for audit log',
+                    title='Go to search form for audit log',
                 ),
                 self._app.anchor(
                     'search', 'List all',
@@ -270,7 +271,7 @@ class AuditContext(NamingContexts):
                         ('filterstr', u'(objectClass=auditObject)'),
                         ('scope', str(ldap0.SCOPE_ONELEVEL)),
                     ],
-                    title=u'List audit log entries of all operations',
+                    title='List audit log entries of all operations',
                 ),
                 self._app.anchor(
                     'search', 'List writes',
@@ -279,7 +280,7 @@ class AuditContext(NamingContexts):
                         ('filterstr', u'(objectClass=auditWriteObject)'),
                         ('scope', str(ldap0.SCOPE_ONELEVEL)),
                     ],
-                    title=u'List audit log entries of all write operations',
+                    title='List audit log entries of all write operations',
                 ),
             ])
         return web2ldapcnf.command_link_separator.join(res)
@@ -308,6 +309,9 @@ class ReqMod(OctetString, DirectoryString):
     desc: str = 'List of modifications/old values'
     known_modtypes = {b'+', b'-', b'=', b'#', b''}
 
+    def _validate(self, attrValue: bytes) -> bool:
+        return OctetString._validate(self, attrValue)
+
     def display(self, valueindex=0, commandbutton=False) -> str:
         if self._av == b':':
             # magic value used for fixing OpenLDAP ITS#6545
@@ -432,7 +436,7 @@ class ReqEntryUUID(UUID):
                         str(self._app.ls.get_search_root(self._app.ls.uc_decode(self._entry['reqDN'][0])[0])),
                     ),
                 ),
-                title=u'Search entry by UUID',
+                title='Search entry by UUID',
             )
         ))
 
@@ -462,7 +466,7 @@ class ReqSession(Integer):
                     ('search_option', web2ldap.app.searchform.SEARCH_OPT_IS_EQUAL),
                     ('search_string', self.av_u),
                 ),
-                title=u'Search all audit entries with same session number',
+                title='Search all audit entries with same session number',
             )
         ))
 
@@ -473,6 +477,37 @@ syntax_registry.reg_at(
 )
 
 
+class ReqDN(DistinguishedName):
+    oid: str = 'ReqDN-oid'
+    desc: str = 'Target DN of request'
+    ref_attrs = (
+        ('reqDN', 'Same target', None, 'Search all entries with same target DN'),
+    )
+
+
+syntax_registry.reg_at(
+    ReqDN.oid, [
+        '1.3.6.1.4.1.4203.666.11.5.1.1', 'reqDN', # reqDN
+    ]
+)
+
+
+class ReqAuthzID(DistinguishedName):
+    oid: str = 'ReqAuthzID-oid'
+    desc: str = 'Authorization DN'
+    ref_attrs = (
+        ('reqAuthzID', 'Same authz-DN', None, 'Search all entries with same authz DN'),
+    )
+
+
+syntax_registry.reg_at(
+    ReqAuthzID.oid, [
+        'reqAuthzID',
+        '1.3.6.1.4.1.4203.666.11.5.1.6', # reqAuthzID
+    ]
+)
+
+
 #---------------------------------------------------------------------------
 # General
 #---------------------------------------------------------------------------
@@ -487,8 +522,6 @@ syntax_registry.reg_at(
     AuthzDN.oid, [
         'monitorConnectionAuthzDN',
         '1.3.6.1.4.1.4203.666.1.55.7', # monitorConnectionAuthzDN
-        'reqAuthzID',
-        '1.3.6.1.4.1.4203.666.11.5.1.6', # reqAuthzID
     ]
 )
 
@@ -518,7 +551,7 @@ class OpenLDAPSpecialBackendSuffix(NamingContexts):
                     u'(&(objectClass=olcDatabaseConfig)(olcDatabase=%s))' % (attr_type_u),
                 ),
             ),
-            title=u'Search for configuration entry below %s' % (config_context),
+            title='Search for configuration entry below %s' % (config_context),
         )
 
 syntax_registry.reg_at(
@@ -538,7 +571,6 @@ syntax_registry.reg_at(
 syntax_registry.reg_at(
     DistinguishedName.oid, [
         'entryDN',
-        'reqDN',
     ]
 )
 
