@@ -5,6 +5,8 @@ web2ldap plugin classes for attributes defined for pilotPerson
 see also RFC1274
 """
 
+from typing import Dict
+
 from web2ldap.app.schema.syntaxes import SelectList, syntax_registry
 
 
@@ -12,16 +14,16 @@ class MailPreferenceOption(SelectList):
     oid: str = 'MailPreferenceOption-oid'
     desc: str = 'RFC1274: mail preference option syntax'
 
-    attr_value_dict = {
-        u'': u'',
-        u'0': u'no-list-inclusion',
-        u'1': u'any-list-inclusion',
-        u'2': u'professional-list-inclusion',
+    attr_value_dict: Dict[str, str] = {
+        '': '',
+        '0': 'no-list-inclusion',
+        '1': 'any-list-inclusion',
+        '2': 'professional-list-inclusion',
     }
 
 syntax_registry.reg_at(
     MailPreferenceOption.oid, [
-        '0.9.2342.19200300.100.1.47', # mailPreferenceOption
+        '0.9.2342.19200300.100.1.47',  # mailPreferenceOption
     ]
 )
 
