@@ -3,6 +3,8 @@
 web2ldap plugin classes for attributes defined for subentries (see RFC 3672)
 """
 
+from typing import Dict
+
 from web2ldap.app.schema.syntaxes import GSER, SelectList, syntax_registry
 
 
@@ -17,14 +19,13 @@ class AdministrativeRole(SelectList):
         'RFC 3672: indicate that the associated administrative'
         ' area is concerned with one or more administrative roles'
     )
-
-    attr_value_dict = {
-        u'2.5.23.1': u'autonomousArea',
-        u'2.5.23.2': u'accessControlSpecificArea',
-        u'2.5.23.3': u'accessControlInnerArea',
-        u'2.5.23.4': u'subschemaAdminSpecificArea',
-        u'2.5.23.5': u'collectiveAttributeSpecificArea',
-        u'2.5.23.6': u'collectiveAttributeInnerArea',
+    attr_value_dict: Dict[str, str] = {
+        '2.5.23.1': 'autonomousArea',
+        '2.5.23.2': 'accessControlSpecificArea',
+        '2.5.23.3': 'accessControlInnerArea',
+        '2.5.23.4': 'subschemaAdminSpecificArea',
+        '2.5.23.5': 'collectiveAttributeSpecificArea',
+        '2.5.23.6': 'collectiveAttributeInnerArea',
     }
 
 syntax_registry.reg_at(
