@@ -5,7 +5,7 @@ web2ldap.app.read: Read single entry and output as HTML or vCard
 web2ldap - a web-based LDAP Client,
 see https://www.web2ldap.de for details
 
-(c) 1998-2020 by Michael Stroeder <michael@stroeder.com>
+(c) 1998-2021 by Michael Stroeder <michael@stroeder.com>
 
 This software is distributed under the terms of the
 Apache License Version 2.0 (Apache-2.0)
@@ -26,6 +26,7 @@ import web2ldap.app.core
 import web2ldap.app.cnf
 import web2ldap.app.gui
 import web2ldap.app.schema
+from web2ldap.log import logger
 from web2ldap.app.schema.syntaxes import syntax_registry
 from web2ldap.msbase import GrabKeys
 from web2ldap.app.schema.viewer import schema_anchor
@@ -54,7 +55,7 @@ def get_vcard_template(app, object_classes):
     template_oc = list(current_oc_set.intersection(template_dict.data.keys()))
     if not template_oc:
         return None
-    return web2ldap.app.gui.GetVariantFilename(template_dict[template_oc[0]], app.form.accept_language)
+    return web2ldap.app.gui.get_variant_filename(template_dict[template_oc[0]], app.form.accept_language)
 
 
 def generate_vcard(template_str, vcard_entry):
@@ -194,30 +195,36 @@ class DisplayEntry(UserDict):
         # Templates defined => display the entry with the help of the template
         used_templates = set()
         displayed_attrs = set()
-        error_msg = None
         for oc_set in (structural_oc, abstract_oc, auxiliary_oc):
             for oc in oc_set:
-                try:
-                    read_template_filename = read_template_dict[oc]
-                except KeyError:
-                    error_msg = 'Template file not found'
+                read_template_filename = read_template_dict[oc]
+                logger.debug('Template file name %r defined for %r', read_template_dict[oc], oc)
+                if not read_template_filename:
+                    logger.warning('Ignoring empty template file name for %r', oc)
                     continue
-                read_template_filename = web2ldap.app.gui.GetVariantFilename(
+                read_template_filename = web2ldap.app.gui.get_variant_filename(
                     read_template_filename,
                     self._app.form.accept_language,
                 )
                 if read_template_filename in used_templates:
                     # template already processed
+                    logger.debug(
+                        'Skipping already processed template file name %r for %r',
+                        read_template_dict[oc],
+                        oc,
+                    )
                     continue
                 used_templates.add(read_template_filename)
-                if not read_template_filename:
-                    error_msg = 'Empty template filename'
-                    continue
                 try:
                     with open(read_template_filename, 'rb') as template_file:
                         template_str = template_file.read().decode('utf-8')
-                except IOError:
-                    error_msg = 'I/O error reading template file'
+                except IOError as err:
+                    logger.error(
+                        'Error reading template file %r for %r: %s',
+                        read_template_dict[oc],
+                        oc,
+                        err,
+                    )
                     continue
                 template_attr_oid_set = {
                     self.entry._s.get_oid(ldap0.schema.models.AttributeType, attr_type_name)
@@ -226,13 +233,6 @@ class DisplayEntry(UserDict):
                 if display_duplicate_attrs or not displayed_attrs.intersection(template_attr_oid_set):
                     self._app.outf.write(template_str % self)
                     displayed_attrs.update(template_attr_oid_set)
-        if error_msg:
-            self._app.outf.write(
-                '<p class="ErrorMessage">%s! (object class <var>%r</var>)</p>' % (
-                    error_msg,
-                    oc,
-                )
-            )
         return displayed_attrs # template_output()
 
 
@@ -463,7 +463,7 @@ def w2l_read(app):
             app,
             '',
             web2ldap.app.gui.main_menu(app),
-            context_menu_list=web2ldap.app.gui.ContextMenuSingleEntry(
+            context_menu_list=web2ldap.app.gui.context_menu_single_entry(
                 app,
                 vcard_link=not get_vcard_template(app, entry.get('objectClass', [])) is None,
                 dds_link=b'dynamicObject' in entry.get('objectClass', []),
