@@ -5,7 +5,7 @@ web2ldap.app.schema.syntaxes: classes for known attribute types
 web2ldap - a web-based LDAP Client,
 see https://www.web2ldap.de for details
 
-(c) 1998-2020 by Michael Stroeder <michael@stroeder.com>
+(c) 1998-2021 by Michael Stroeder <michael@stroeder.com>
 
 This software is distributed under the terms of the
 Apache License Version 2.0 (Apache-2.0)
@@ -25,7 +25,15 @@ import time
 import json
 import inspect
 import warnings
-from typing import List, Optional
+from typing import (
+    Callable,
+    Dict,
+    List,
+    Optional,
+    Pattern,
+    Sequence,
+    Tuple,
+)
 
 try:
     import defusedxml.ElementTree
@@ -245,14 +253,14 @@ class LDAPSyntax:
     mimeType: str = 'application/octet-stream'
     fileExt: str = 'bin'
     editable: bool = True
-    reObj = None
+    reObj: Optional[Pattern[str]] = None
     input_pattern: Optional[str] = None
-    searchSep = '<br>'
-    readSep = '<br>'
-    fieldSep = '<br>'
-    fieldCountAssert = 1
-    simpleSanitizers = tuple()
-    showValueButton = True
+    searchSep: str = '<br>'
+    readSep: str = '<br>'
+    fieldSep: str = '<br>'
+    fieldCountAssert: int = 1
+    simpleSanitizers: Sequence[Callable] = (())
+    showValueButton: bool = True
 
     def __init__(
             self,
@@ -409,7 +417,7 @@ class LDAPSyntax:
     def formFields(self):
         return (self.formField(),)
 
-    def formField(self) -> str:
+    def formField(self) -> web2ldap.web.forms.Field:
         input_field = web2ldap.web.forms.Input(
             self._at,
             ': '.join([self._at, self.desc]),
@@ -435,7 +443,7 @@ class Binary(LDAPSyntax):
     desc: str = 'Binary'
     editable: bool = False
 
-    def formField(self) -> str:
+    def formField(self) -> web2ldap.web.forms.Field:
         f = web2ldap.web.forms.File(
             self._at,
             ': '.join([self._at, self.desc]),
@@ -468,8 +476,8 @@ class Audio(Binary):
     fileExt: str = 'au'
 
     def _validate(self, attrValue: bytes) -> bool:
-        fileobj = BytesIO(attrValue)
-        res = sndhdr.test_au(attrValue, fileobj)
+        with BytesIO(attrValue) as fileobj:
+            res = sndhdr.test_au(attrValue, fileobj)
         return res is not None
 
     def display(self, valueindex=0, commandbutton=False) -> str:
@@ -520,7 +528,7 @@ class DistinguishedName(DirectoryString):
     desc: str = 'Distinguished Name'
     isBindDN = False
     hasSubordinates = False
-    ref_attrs = None
+    ref_attrs: Optional[Sequence[Tuple[Optional[str], str, Optional[str], str]]] = None
 
     def _validate(self, attrValue: bytes) -> bool:
         return is_dn(self._app.ls.uc_decode(attrValue)[0])
@@ -554,7 +562,7 @@ class DistinguishedName(DirectoryString):
                         ('dn', self._dn),
                         ('login_who', self.av_u),
                     ],
-                    title=u'Connect and bind new session as\r\n%s' % (self.av_u)
+                    title='Connect and bind new session as\r\n%s' % (self.av_u)
                 ),
             )
         # If self.ref_attrs is not empty then add links for searching back-linking entries
@@ -880,17 +888,17 @@ class NullTerminatedDirectoryString(DirectoryString):
     desc: str = 'Directory String terminated by null-byte'
 
     def sanitize(self, attrValue: bytes) -> bytes:
-        return attrValue + chr(0)
+        return attrValue + b'\x00'
 
     def _validate(self, attrValue: bytes) -> bool:
-        return attrValue.endswith(chr(0))
+        return attrValue.endswith(b'\x00')
 
     def formValue(self) -> str:
-        return self._app.ls.uc_decode((self._av or chr(0))[:-1])[0]
+        return self._app.ls.uc_decode((self._av or b'\x00')[:-1])[0]
 
     def display(self, valueindex=0, commandbutton=False) -> str:
         return self._app.form.utf2display(
-            self._app.ls.uc_decode((self._av or chr(0))[:-1])[0]
+            self._app.ls.uc_decode((self._av or b'\x00')[:-1])[0]
         )
 
 
@@ -947,7 +955,7 @@ class Integer(IA5String):
         except ValueError:
             return attrValue
 
-    def formField(self) -> str:
+    def formField(self) -> web2ldap.web.forms.Field:
         form_value = self.formValue()
         max_len = self._maxlen(form_value)
         input_field = web2ldap.web.forms.Input(
@@ -1117,11 +1125,12 @@ class Image(Binary):
 
     def sanitize(self, attrValue: bytes) -> bytes:
         if not self._validate(attrValue) and PILImage:
-            imgfile = BytesIO(attrValue)
             try:
-                im = PILImage.open(imgfile)
-                imgfile.seek(0)
-                im.save(imgfile, self.imageFormat)
+                with BytesIO(attrValue) as imgfile:
+                    im = PILImage.open(imgfile)
+                    imgfile.seek(0)
+                    im.save(imgfile, self.imageFormat)
+                    attrValue = imgfile.getvalue()
             except Exception as err:
                 logger.warning(
                     'Error converting image data (%d bytes) to %s: %r',
@@ -1129,8 +1138,6 @@ class Image(Binary):
                     self.imageFormat,
                     err,
                 )
-            else:
-                attrValue = imgfile.getvalue()
         return attrValue
 
     def display(self, valueindex=0, commandbutton=False) -> str:
@@ -1138,9 +1145,9 @@ class Image(Binary):
         width, height = None, None
         size_attr_html = ''
         if PILImage:
-            f = BytesIO(self._av)
             try:
-                im = PILImage.open(f)
+                with BytesIO(self._av) as imgfile:
+                    im = PILImage.open(imgfile)
             except IOError:
                 pass
             else:
@@ -1222,10 +1229,16 @@ class OID(IA5String):
     oid: str = '1.3.6.1.4.1.1466.115.121.1.38'
     desc: str = 'OID'
     reObj = re.compile(r'^([a-zA-Z]+[a-zA-Z0-9;-]*|[0-2]?\.([0-9]+\.)*[0-9]+)$')
+    no_val_button_attrs = frozenset((
+        'objectclass',
+        'structuralobjectclass',
+        '2.5.4.0',
+        '2.5.21.9',
+    ))
 
     def valueButton(self, command, row, mode, link_text=None):
         at = self._at.lower()
-        if at in {'objectclass', 'structuralobjectclass', '2.5.4.0', '2.5.21.9'}:
+        if at in self.no_val_button_attrs:
             return ''
         return IA5String.valueButton(self, command, row, mode, link_text=link_text)
 
@@ -1305,7 +1318,7 @@ class LDAPUrl(Uri):
                 commandbuttonstr = ''
         except ValueError:
             return '<strong>Not a valid LDAP URL:</strong> %s' % (
-                self._app.form.utf2display(repr(self._av).decode('ascii'))
+                self._app.form.utf2display(repr(self._av))
             )
         return '<table><tr><td>%s</td><td><a href="%s">%s</a></td></tr></table>' % (
             commandbuttonstr,
@@ -1361,7 +1374,7 @@ class OctetString(Binary):
             )
         ))
 
-    def formField(self) -> str:
+    def formField(self) -> web2ldap.web.forms.Field:
         form_value = self.formValue()
         return web2ldap.web.forms.Textarea(
             self._at,
@@ -1412,7 +1425,7 @@ class MultilineText(DirectoryString):
         ]
         return '\r\n'.join(splitted_lines)
 
-    def formField(self) -> str:
+    def formField(self) -> web2ldap.web.forms.Field:
         form_value = self.formValue()
         return web2ldap.web.forms.Textarea(
             self._at,
@@ -1584,8 +1597,11 @@ class Date(IA5String):
 
     def _validate(self, attrValue: bytes) -> bool:
         try:
-            datetime.datetime.strptime(attrValue, self.storageFormat)
-        except ValueError:
+            datetime.datetime.strptime(
+                self._app.ls.uc_decode(attrValue)[0],
+                self.storageFormat
+            )
+        except (UnicodeDecodeError, ValueError):
             return False
         return True
 
@@ -1735,11 +1751,14 @@ class Timespan(Integer):
         if not self._av:
             return ''
         try:
-            result = web2ldap.app.gui.ts2repr(self.time_divisors, self.sep, int(self._av))
+            result = web2ldap.app.gui.ts2repr(self.time_divisors, self.sep, self._av)
         except ValueError:
             result = Integer.formValue(self)
         return result
 
+    def formField(self) -> web2ldap.web.forms.Field:
+        return IA5String.formField(self)
+
     def display(self, valueindex=0, commandbutton=False) -> str:
         try:
             result = self._app.form.utf2display('%s (%s)' % (
@@ -1757,12 +1776,17 @@ class SelectList(DirectoryString):
     should not be used directly
     """
     oid: str = 'SelectList-oid'
-    attr_value_dict = {}   # Mapping attribute value to attribute description
-    input_fallback = True  # Fallback to normal input field if attr_value_dict is empty
+    attr_value_dict: Dict[str, str] = {}   # Mapping attribute value to attribute description
+    input_fallback: bool = True  # Fallback to normal input field if attr_value_dict is empty
+    desc_sep: str = ' '
+    tag_tmpl: Dict[bool, str] = {
+        False: '{attr_text}: {attr_value}',
+        True: '<span title="{attr_title}">{attr_text}:{sep}{attr_value}</span>',
+    }
 
     def _get_attr_value_dict(self):
         # Enable empty value in any case
-        attr_value_dict = {'': '-/-'}
+        attr_value_dict: Dict[str, str] = {'': '-/-'}
         attr_value_dict.update(self.attr_value_dict)
         return attr_value_dict
 
@@ -1795,12 +1819,12 @@ class SelectList(DirectoryString):
         )
 
     def _validate(self, attrValue: bytes) -> bool:
-        attr_value_dict = self._get_attr_value_dict()
+        attr_value_dict: Dict[str, str] = self._get_attr_value_dict()
         return self._app.ls.uc_decode(attrValue)[0] in attr_value_dict
 
     def display(self, valueindex=0, commandbutton=False) -> str:
         attr_value_str = DirectoryString.display(self, valueindex, commandbutton)
-        attr_value_dict = self._get_attr_value_dict()
+        attr_value_dict: Dict[str, str] = self._get_attr_value_dict()
         try:
             attr_value_desc = attr_value_dict[self.av_u]
         except KeyError:
@@ -1811,18 +1835,15 @@ class SelectList(DirectoryString):
             attr_text, attr_title = attr_value_desc, None
         if attr_text == attr_value_str:
             return attr_value_str
-        if attr_title:
-            tag_tmpl = '<span title="{attr_title}">{attr_text}: {attr_value}</span>'
-        else:
-            tag_tmpl = '{attr_text}: {attr_value}'
-        return tag_tmpl.format(
+        return self.tag_tmpl[bool(attr_title)].format(
             attr_value=attr_value_str,
+            sep=self.desc_sep,
             attr_text=self._app.form.utf2display(attr_text),
             attr_title=self._app.form.utf2display(attr_title or '')
         )
 
-    def formField(self) -> str:
-        attr_value_dict = self._get_attr_value_dict()
+    def formField(self) -> web2ldap.web.forms.Field:
+        attr_value_dict: Dict[str, str] = self._get_attr_value_dict()
         if self.input_fallback and \
            (not attr_value_dict or not list(filter(None, attr_value_dict.keys()))):
             return DirectoryString.formField(self)
@@ -1844,13 +1865,13 @@ class PropertiesSelectList(SelectList):
     constructed and validated by reading a properties file.
     """
     oid: str = 'PropertiesSelectList-oid'
-    properties_pathname = None
-    properties_charset = 'utf-8'
-    properties_delimiter = '='
+    properties_pathname: Optional[str] = None
+    properties_charset: str = 'utf-8'
+    properties_delimiter: str = '='
 
     def _get_attr_value_dict(self):
-        attr_value_dict = SelectList._get_attr_value_dict(self)
-        real_path_name = web2ldap.app.gui.GetVariantFilename(
+        attr_value_dict: Dict[str, str] = SelectList._get_attr_value_dict(self)
+        real_path_name = web2ldap.app.gui.get_variant_filename(
             self.properties_pathname,
             self._app.form.accept_language
         )
@@ -1870,9 +1891,9 @@ class DynamicValueSelectList(SelectList, DirectoryString):
     constructed and validated by internal LDAP search.
     """
     oid: str = 'DynamicValueSelectList-oid'
-    ldap_url = None
-    valuePrefix = ''
-    valueSuffix = ''
+    ldap_url: Optional[str] = None
+    valuePrefix: str = ''
+    valueSuffix: str = ''
 
     def __init__(self, app, dn: str, schema, attrType: str, attrValue: bytes, entry=None):
         self.lu_obj = ldap0.ldapurl.LDAPUrl(self.ldap_url)
@@ -1940,7 +1961,7 @@ class DynamicValueSelectList(SelectList, DirectoryString):
                     if self.lu_obj.attrs[0].lower() == self.lu_obj.attrs[1].lower():
                         display_text = ''
                     else:
-                        display_text = self._app.form.utf2display(attr_value_desc+u':')
+                        display_text = self._app.form.utf2display(attr_value_desc+':')
                     if commandbutton:
                         link_html = self._app.anchor(
                             'read', '&raquo;',
@@ -1980,7 +2001,7 @@ class DynamicValueSelectList(SelectList, DirectoryString):
         # end of _search_root()
 
     def _get_attr_value_dict(self):
-        attr_value_dict = SelectList._get_attr_value_dict(self)
+        attr_value_dict: Dict[str, str] = SelectList._get_attr_value_dict(self)
         if self.lu_obj.hostport:
             raise ValueError(
                 'Connecting to other server not supported! hostport attribute was %r' % (
@@ -2021,7 +2042,7 @@ class DynamicValueSelectList(SelectList, DirectoryString):
                 ))
                 for attr_value in ldap_result[0].entry_s[list_attr]
             ]
-            attr_value_dict = {
+            attr_value_dict: Dict[str, str] = {
                 u: u
                 for u in attr_values_u
             }
@@ -2099,10 +2120,10 @@ class DynamicDNSelectList(DynamicValueSelectList, DistinguishedName):
             except (KeyError, IndexError):
                 display_text = ''
             else:
-                display_text = self._app.form.utf2display(attr_value_desc+u': ')
+                display_text = self._app.form.utf2display(attr_value_desc+': ')
         else:
             display_text = ''
-        return ''.join((
+        return self.desc_sep.join((
             display_text,
             DistinguishedName.display(self, valueindex, commandbutton)
         ))
@@ -2153,13 +2174,13 @@ class Boolean(SelectList, IA5String):
     """
     oid: str = '1.3.6.1.4.1.1466.115.121.1.7'
     desc: str = 'Boolean'
-    attr_value_dict = {
+    attr_value_dict: Dict[str, str] = {
         'TRUE': 'TRUE',
         'FALSE': 'FALSE',
     }
 
     def _get_attr_value_dict(self):
-        attr_value_dict = SelectList._get_attr_value_dict(self)
+        attr_value_dict: Dict[str, str] = SelectList._get_attr_value_dict(self)
         if self._av and self._av.lower() == self._av:
             for key, val in attr_value_dict.items():
                 del attr_value_dict[key]
@@ -2207,8 +2228,8 @@ class BitArrayInteger(MultilineText, Integer):
     value is interpreted as binary flags
     """
     oid: str = 'BitArrayInteger-oid'
-    flag_desc_table = tuple()
-    true_false_desc = {
+    flag_desc_table: Sequence[Tuple[str, int]] = tuple()
+    true_false_desc: Dict[bool, str] = {
         False: '-',
         True: '+',
     }
@@ -2257,7 +2278,7 @@ class BitArrayInteger(MultilineText, Integer):
         ]
         return '\r\n'.join(flag_lines)
 
-    def formField(self) -> str:
+    def formField(self) -> web2ldap.web.forms.Field:
         form_value = self.formValue()
         return web2ldap.web.forms.Textarea(
             self._at,
@@ -2484,7 +2505,7 @@ class HashAlgorithmOID(SelectList, AlgorithmOID):
     """
     oid: str = 'HashAlgorithmOID-oid'
     desc: str = 'values from https://www.iana.org/assignments/hash-function-text-names/'
-    attr_value_dict = {
+    attr_value_dict: Dict[str, str] = {
         '1.2.840.113549.2.2': 'md2',          # [RFC3279]
         '1.2.840.113549.2.5': 'md5',          # [RFC3279]
         '1.3.14.3.2.26': 'sha-1',             # [RFC3279]
@@ -2501,7 +2522,7 @@ class HMACAlgorithmOID(SelectList, AlgorithmOID):
     """
     oid: str = 'HMACAlgorithmOID-oid'
     desc: str = 'values from RFC 8018'
-    attr_value_dict = {
+    attr_value_dict: Dict[str, str] = {
         # from RFC 8018
         '1.2.840.113549.2.7': 'hmacWithSHA1',
         '1.2.840.113549.2.8': 'hmacWithSHA224',
@@ -2523,7 +2544,7 @@ class ComposedAttribute(LDAPSyntax):
     more precisely only the "first" attribute value is used.
     """
     oid: str = 'ComposedDirectoryString-oid'
-    compose_templates = ()
+    compose_templates: Sequence[str] = ()
 
     class SingleValueDict(dict):
         """
@@ -2566,7 +2587,7 @@ class ComposedAttribute(LDAPSyntax):
             return attrValues
         return attr_values
 
-    def formField(self) -> str:
+    def formField(self) -> web2ldap.web.forms.Field:
         """
         composed attributes must only have hidden input field
         """
@@ -2589,7 +2610,7 @@ class LDAPv3ResultCode(SelectList):
     """
     oid: str = 'LDAPResultCode-oid'
     desc: str = 'LDAPv3 declaration of resultCode in (see RFC 4511)'
-    attr_value_dict = {
+    attr_value_dict: Dict[str, str] = {
         '0': 'success',
         '1': 'operationsError',
         '2': 'protocolError',
