@@ -5,7 +5,7 @@ web2ldap.app.schema.viewer -  Display LDAPv3 schema
 web2ldap - a web-based LDAP Client,
 see https://www.web2ldap.de for details
 
-(c) 1998-2020 by Michael Stroeder <michael@stroeder.com>
+(c) 1998-2021 by Michael Stroeder <michael@stroeder.com>
 
 This software is distributed under the terms of the
 Apache License Version 2.0 (Apache-2.0)
@@ -142,7 +142,9 @@ def schema_anchors(app, se_names, se_class):
 
 
 def schema_tree_html(app, schema, se_class, se_tree, se_oid, level):
-    """HTML output for browser"""
+    """
+    returns HTML for displaying a schema descriptions inheritance tree
+    """
     app.outf.write('<dl>')
     se_obj = schema.get_obj(se_class, se_oid)
     if se_obj is not None:
