@@ -5,7 +5,7 @@ web2ldap.app.search: do a search and return results in several formats
 web2ldap - a web-based LDAP Client,
 see https://www.web2ldap.de for details
 
-(c) 1998-2020 by Michael Stroeder <michael@stroeder.com>
+(c) 1998-2021 by Michael Stroeder <michael@stroeder.com>
 
 This software is distributed under the terms of the
 Apache License Version 2.0 (Apache-2.0)
@@ -50,6 +50,17 @@ import web2ldap.__about__
 
 SEARCH_NOOP_TIMEOUT = 5.0
 
+SEARCH_BOOKMARK_TMPL = """
+<a
+  href="{baseUrl}?{ldapUrl}"
+  target="_blank"
+  rel="bookmark"
+  title="Bookmark for these search results"
+>
+  Bookmark
+</a>
+"""
+
 PAGE_COMMAND_TMPL = """
 <nav><table>
   <tr>
@@ -269,8 +280,8 @@ class ExcelWriter(web2ldap.ldaputil.asynch.AsyncSearchHandler):
                     csv_col_value = binascii.b2a_base64(attr_value).decode('ascii').replace('\r', '').replace('\n', '')
                 csv_col_value_list.append(csv_col_value)
             csv_row_list.append('\r\n'.join(csv_col_value_list))
-        for col in range(len(csv_row_list)):
-            self._worksheet.write(self._row_counter, col, csv_row_list[col])
+        for col, val in enumerate(csv_row_list):
+            self._worksheet.write(self._row_counter, col, val)
         self._row_counter += 1
 
 
@@ -800,19 +811,10 @@ def w2l_search(app):
                     elif search_resminindex+search_resnumber <= resind:
                         page_command_list[3] = page_next_link
 
-            search_bookmark = """
-                <a
-                  href="{baseUrl}?{ldapUrl}"
-                  target="_blank"
-                  rel="bookmark"
-                  title="Bookmark for these search results"
-                >
-                  Bookmark
-                </a>
-                """.format(
-                    baseUrl=escape_html(app.form.script_name),
-                    ldapUrl=str(search_ldap_url),
-                )
+            search_bookmark = SEARCH_BOOKMARK_TMPL.format(
+                baseUrl=escape_html(app.form.script_name),
+                ldapUrl=str(search_ldap_url),
+            )
             result_message = '\n<p>Search results %d - %d %s / <a href="#params" title="See search parameters and export options">Params</a> / %s</p>\n' % (
                 search_resminindex+1,
                 resind,
@@ -1006,13 +1008,8 @@ def w2l_search(app):
 
                 # write the search result table row
                 app.outf.write(
-                    """
-                    <tr>
-                      <td class="CT">\n%s\n</td>
-                      <td>\n%s\n</td>
-                    </tr>
-                    """ % (
-                        '\n'.join(command_table),
+                    '<tr><td class="CT">{0}</td><td>{1}</td></tr>\n'.format(
+                        ''.join(command_table),
                         result_dd_str
                     )
                 )
