@@ -2,7 +2,7 @@
 """
 web2ldap.web.forms - class library for handling <FORM> input
 
-(c) 1998-2020 by Michael Stroeder <michael@stroeder.com>
+(c) 1998-2021 by Michael Stroeder <michael@stroeder.com>
 
 This software is distributed under the terms of the
 Apache License Version 2.0 (Apache-2.0)
@@ -15,6 +15,7 @@ import sys
 import re
 import urllib.parse
 import uuid
+from typing import List
 
 from . import escape_html
 from . import helper
@@ -157,11 +158,7 @@ class Field:
         if (not self._re is None) and value:
             rm = self._re.match(value)
             if rm is None:
-                raise InvalidValueFormat(
-                    self.name,
-                    self.text,
-                    value.encode(self.charset)
-                )
+                raise InvalidValueFormat(self.name, self.text, value)
 
     def _validate_val_count(self):
         if len(self.value) >= self.maxValues:
@@ -413,11 +410,7 @@ class Radio(Field):
         You might override this method to change this behaviour.
         """
         if value and (not value in self.optionValues):
-            raise InvalidValueFormat(
-                self.name,
-                self.text.encode(self.charset),
-                value.encode(self.charset)
-            )
+            raise InvalidValueFormat(self.name, self.text, value)
 
     def setOptions(self, options):
         self.optionValues = {}
@@ -676,19 +669,8 @@ class Checkbox(Field):
 class FormException(Exception):
     """
     Base exception class to indicate form processing errors.
-
-    Attributes:
-    args          unstructured List of parameters
     """
 
-    def __init__(self, *args, **kwargs):
-        self.args = args
-        for key, value in kwargs.items():
-            setattr(self, key, value)
-
-    def html(self):
-        return escape_html(str(self))
-
 
 class InvalidFormEncoding(FormException):
     """
@@ -699,7 +681,7 @@ class InvalidFormEncoding(FormException):
     """
 
     def __init__(self, param):
-        FormException.__init__(self, ())
+        FormException.__init__(self)
         self.param = param
 
     def __str__(self):
@@ -715,15 +697,15 @@ class ContentLengthExceeded(FormException):
     maxContentLength      maximum valid content length
     """
 
-    def __init__(self, content_length, maxContentLength):
-        FormException.__init__(self, ())
+    def __init__(self, content_length: int, max_length: int):
+        FormException.__init__(self)
         self.content_length = content_length
-        self.maxContentLength = maxContentLength
+        self.max_length = max_length
 
     def __str__(self):
         return 'Input length of %d bytes exceeded the maximum of %d bytes.' % (
             self.content_length,
-            self.maxContentLength
+            self.max_length
         )
 
 
@@ -735,8 +717,8 @@ class InvalidFieldName(FormException):
     name          name of undeclared field
     """
 
-    def __init__(self, name):
-        FormException.__init__(self, ())
+    def __init__(self, name: str):
+        FormException.__init__(self)
         self.name = name
 
     def __str__(self):
@@ -751,8 +733,8 @@ class ParamsMissing(FormException):
     missingParamNames     list of strings containing all names of missing
                           input fields.
     """
-    def __init__(self, missingParamNames):
-        FormException.__init__(self, ())
+    def __init__(self, missingParamNames: List[str]):
+        FormException.__init__(self)
         self.missingParamNames = missingParamNames
 
     def __str__(self):
@@ -776,8 +758,8 @@ class InvalidValueFormat(FormException):
     value         input value received
     """
 
-    def __init__(self, name, text, value):
-        FormException.__init__(self, ())
+    def __init__(self, name: str, text: str, value):
+        FormException.__init__(self)
         self.name = name
         self.text = text
         self.value = value
@@ -799,8 +781,8 @@ class InvalidValueLen(FormException):
     maxValueLen   integer number of maximum value length
     """
 
-    def __init__(self, name, text, valueLen, maxValueLen):
-        FormException.__init__(self, ())
+    def __init__(self, name: str, text: str, valueLen: int, maxValueLen: int):
+        FormException.__init__(self)
         self.name = name
         self.text = text
         self.valueLen = valueLen
@@ -826,8 +808,8 @@ class TooManyValues(FormException):
     maxValueCount         integer number of maximum values with name allowed
     """
 
-    def __init__(self, name, text, valueCount, maxValueCount):
-        FormException.__init__(self, ())
+    def __init__(self, name: str, text: str, valueCount: int, maxValueCount: int):
+        FormException.__init__(self)
         self.name = name
         self.text = text
         self.valueCount = valueCount
@@ -989,8 +971,6 @@ class Form:
         elif self.request_method == 'GET':
             query_string = self.env.get('QUERY_STRING', '')
 
-        self.inf.close()
-
         if not query_string:
             return
 
